@@ -46,12 +46,24 @@ namespace Ogre
         0, -1,  0,  0,      // z
         0,  0,  0,  1); // w
 
+    /// Builds a standard view matrix out of a given position, direction and up vector.
+    static Affine3 buildViewMatrix(const Vector3& pos, const Vector3& dir, const Vector3& up)
+    {
+        Matrix3 Rt = Math::lookRotation(-dir, up).transpose();
+        Matrix4 m;
+        m = Rt;
+        m.setTrans(-Rt * pos);
+        return Affine3(m); // make sure projective part is identity
+    }
+
     FocusedShadowCameraSetup::FocusedShadowCameraSetup(bool useAggressiveRegion)
         : mTempFrustum(OGRE_NEW Frustum())
+        , mLightFrustumCameraNode(NULL)
         , mLightFrustumCamera(OGRE_NEW Camera("TEMP LIGHT INTERSECT CAM", NULL))
-        , mLightFrustumCameraCalculated(false)
         , mUseAggressiveRegion(useAggressiveRegion)
+        , mLightFrustumCameraCalculated(false)
     {
+        mLightFrustumCamera->_notifyAttached(&mLightFrustumCameraNode);
         mTempFrustum->setProjectionType(PT_PERSPECTIVE);
     }
 
@@ -60,9 +72,9 @@ namespace Ogre
     //-----------------------------------------------------------------------
     void FocusedShadowCameraSetup::calculateShadowMappingMatrix(const SceneManager& sm,
         const Camera& cam, const Light& light, Affine3 *out_view, Matrix4 *out_proj,
-        Camera *out_cam) const
+        Frustum *out_cam) const
     {
-        // get the shadow frustum's far distance
+        // get the shadow far distance
         Real shadowDist = light.getShadowFarDistance();
         if (!shadowDist)
         {
@@ -71,6 +83,12 @@ namespace Ogre
         }
         Real shadowOffset = shadowDist * sm.getShadowDirLightTextureOffset();
 
+        if (out_cam)
+        {
+            // common options
+            out_cam->setNearClipDistance(light._deriveShadowNearClipDistance(&cam));
+            out_cam->setFarClipDistance(light._deriveShadowFarClipDistance());
+        }
 
         if (light.getType() == Light::LT_DIRECTIONAL)
         {
@@ -102,10 +120,9 @@ namespace Ogre
             if (out_cam != NULL)
             {
                 out_cam->setProjectionType(PT_ORTHOGRAPHIC);
-                out_cam->setDirection(light.getDerivedDirection());
-                out_cam->setPosition(cam.getDerivedPosition());
+                out_cam->getParentSceneNode()->setDirection(light.getDerivedDirection(), Node::TS_WORLD);
+                out_cam->getParentSceneNode()->setPosition(cam.getDerivedPosition());
                 out_cam->setFOVy(Degree(90));
-                out_cam->setNearClipDistance(shadowOffset);
             }
         }
         else if (light.getType() == Light::LT_POINT)
@@ -134,7 +151,7 @@ namespace Ogre
                 mTempFrustum->setFOVy(Degree(120));
 
                 mTempFrustum->setNearClipDistance(light._deriveShadowNearClipDistance(&cam));
-                mTempFrustum->setFarClipDistance(light._deriveShadowFarClipDistance(&cam));
+                mTempFrustum->setFarClipDistance(light._deriveShadowFarClipDistance());
 
                 *out_proj = mTempFrustum->getProjectionMatrix();
             }
@@ -143,11 +160,9 @@ namespace Ogre
             if (out_cam != NULL)
             {
                 out_cam->setProjectionType(PT_PERSPECTIVE);
-                out_cam->setDirection(lightDir);
-                out_cam->setPosition(light.getDerivedPosition());
+                out_cam->getParentSceneNode()->setDirection(lightDir, Node::TS_WORLD);
+                out_cam->getParentSceneNode()->setPosition(light.getDerivedPosition());
                 out_cam->setFOVy(Degree(120));
-                out_cam->setNearClipDistance(light._deriveShadowNearClipDistance(&cam));
-                out_cam->setFarClipDistance(light._deriveShadowFarClipDistance(&cam));
             }
         }
         else if (light.getType() == Light::LT_SPOTLIGHT)
@@ -167,7 +182,7 @@ namespace Ogre
                 mTempFrustum->setFOVy(Ogre::Math::Clamp<Radian>(light.getSpotlightOuterAngle() * 1.2, Radian(0), Radian(Math::PI/2.0f)));
 
                 mTempFrustum->setNearClipDistance(light._deriveShadowNearClipDistance(&cam));
-                mTempFrustum->setFarClipDistance(light._deriveShadowFarClipDistance(&cam));
+                mTempFrustum->setFarClipDistance(light._deriveShadowFarClipDistance());
 
                 *out_proj = mTempFrustum->getProjectionMatrix();
             }
@@ -176,11 +191,9 @@ namespace Ogre
             if (out_cam != NULL)
             {
                 out_cam->setProjectionType(PT_PERSPECTIVE);
-                out_cam->setDirection(light.getDerivedDirection());
-                out_cam->setPosition(light.getDerivedPosition());
+                out_cam->getParentSceneNode()->setDirection(light.getDerivedDirection(), Node::TS_WORLD);
+                out_cam->getParentSceneNode()->setPosition(light.getDerivedPosition());
                 out_cam->setFOVy(Ogre::Math::Clamp<Radian>(light.getSpotlightOuterAngle() * 1.2, Radian(0), Radian(Math::PI/2.0f)));
-                out_cam->setNearClipDistance(light._deriveShadowNearClipDistance(&cam));
-                out_cam->setFarClipDistance(light._deriveShadowFarClipDistance(&cam));
             }
         }
     }
@@ -243,7 +256,7 @@ namespace Ogre
         {
             // For directional lights, all we care about is projecting the receivers
             // backwards towards the light, clipped by the camera region
-            mBodyB.clip(receiverBB);
+            mBodyB.clip(receiverBB.intersection(sceneBB));
 
             // Also clip based on shadow far distance if appropriate
             Real farDist = light.getShadowFarDistance();
@@ -382,21 +395,6 @@ namespace Ogre
         return mOut;
     }
     //-----------------------------------------------------------------------
-    Affine3 FocusedShadowCameraSetup::buildViewMatrix(const Vector3& pos, const Vector3& dir,
-        const Vector3& up) const
-    {
-        Vector3 xN = dir.crossProduct(up);
-        xN.normalise();
-        Vector3 upN = xN.crossProduct(dir);
-        upN.normalise();
-
-        Affine3 m(xN.x,     xN.y,       xN.z,       -xN.dotProduct(pos),
-            upN.x,      upN.y,      upN.z,      -upN.dotProduct(pos),
-            -dir.x,     -dir.y, -dir.z, dir.dotProduct(pos));
-
-        return m;
-    }
-    //-----------------------------------------------------------------------
     void FocusedShadowCameraSetup::getShadowCamera (const SceneManager *sm, const Camera *cam, 
         const Viewport *vp, const Light *light, Camera *texCam, size_t iteration) const
     {
@@ -408,7 +406,7 @@ namespace Ogre
         mLightFrustumCameraCalculated = false;
 
         texCam->setNearClipDistance(light->_deriveShadowNearClipDistance(cam));
-        texCam->setFarClipDistance(light->_deriveShadowFarClipDistance(cam));
+        texCam->setFarClipDistance(light->_deriveShadowFarClipDistance());
 
         // calculate standard shadow mapping matrix
         Affine3 LView; Matrix4 LProj;
@@ -418,7 +416,6 @@ namespace Ogre
         const VisibleObjectsBoundsInfo& visInfo = sm->getVisibleObjectsBoundsInfo(texCam);
         AxisAlignedBox sceneBB = visInfo.aabb;
         AxisAlignedBox receiverAABB = sm->getVisibleObjectsBoundsInfo(cam).receiverAabb;
-        sceneBB.merge(receiverAABB);
         sceneBB.merge(cam->getDerivedPosition());
 
         // in case the sceneBB is empty (e.g. nothing visible to the cam) simply
@@ -462,7 +459,7 @@ namespace Ogre
         // - position is the origin
         // - the view direction is the calculated viewDir
         // - the up vector is the y-axis
-        LProj = buildViewMatrix(Vector3::ZERO, viewDir, Vector3::UNIT_Y) * LProj;
+        LProj = Matrix4(Math::lookRotation(-viewDir, Vector3::UNIT_Y).transpose()) * LProj;
 
         // map bodyB to unit cube
         LProj = transformToUnitCube(LProj * LView, mPointListBodyB) * LProj;
