@@ -38,6 +38,7 @@ THE SOFTWARE.
 #include "OgreD3D9Device.h"
 #include "OgreD3D9DeviceManager.h"
 #include "OgreD3D9ResourceManager.h"
+#include "OgreD3D9DepthBuffer.h"
 
 #include <d3dx9.h>
 
@@ -357,6 +358,9 @@ namespace Ogre
             mUsage |= TU_DYNAMIC;
         }
 
+        if(!PixelUtil::isDepth(mFormat))
+            mFormat = TextureManager::getSingleton().getNativeFormat(mTextureType, mFormat, mUsage);
+
         // load based on tex.type
         switch (getTextureType())
         {
@@ -384,15 +388,11 @@ namespace Ogre
 
         // determine which D3D9 pixel format we'll use
         HRESULT hr;
-        D3DFORMAT d3dPF = _chooseD3DFormat(d3d9Device);
-
-        // let's D3DX check the corrected pixel format
-        hr = D3DXCheckTextureRequirements(d3d9Device, NULL, NULL, NULL, 0, &d3dPF, mD3DPool);
+        D3DFORMAT d3dPF = D3D9Mappings::_getPF(mFormat);
 
         // Use D3DX to help us create the texture, this way it can adjust any relevant sizes
         DWORD usage = (mUsage & TU_RENDERTARGET) ? D3DUSAGE_RENDERTARGET : 0;
-        UINT numMips = (mNumRequestedMipmaps == MIP_UNLIMITED) ? 
-                D3DX_DEFAULT : mNumRequestedMipmaps + 1;
+        UINT numMips = (mNumRequestedMipmaps == MIP_UNLIMITED) ? 0 : mNumRequestedMipmaps + 1;
         // Check dynamic textures
         if (mUsage & TU_DYNAMIC)
         {
@@ -464,17 +464,24 @@ namespace Ogre
         else
             textureResources = allocateTextureResources(d3d9Device);
 
+        if(PixelUtil::isDepth(mFormat))
+        {
+            usage = D3DUSAGE_DEPTHSTENCIL;
+            mD3DPool = D3DPOOL_DEFAULT;
+            // we cannot resolve depth on D3D9
+            mFSAAType = D3DMULTISAMPLE_NONE;
+            mFSAA = 0;
+        }
 
         // create the texture
-        hr = D3DXCreateTexture( 
-                d3d9Device,                             // device
+        hr = d3d9Device->CreateTexture(
                 static_cast<UINT>(mSrcWidth),           // width
                 static_cast<UINT>(mSrcHeight),          // height
                 numMips,                                // number of mip map levels
                 usage,                                  // usage
                 d3dPF,                                  // pixel format
                 mD3DPool,
-                &textureResources->pNormTex);           // data pointer
+                &textureResources->pNormTex, NULL);
         // check result and except if failed
         if (FAILED(hr))
         {
@@ -544,15 +551,11 @@ namespace Ogre
 
         // determine which D3D9 pixel format we'll use
         HRESULT hr;
-        D3DFORMAT d3dPF = _chooseD3DFormat(d3d9Device);
-
-        // let's D3DX check the corrected pixel format
-        hr = D3DXCheckCubeTextureRequirements(d3d9Device, NULL, NULL, 0, &d3dPF, mD3DPool);
+        D3DFORMAT d3dPF = D3D9Mappings::_getPF(mFormat);
 
         // Use D3DX to help us create the texture, this way it can adjust any relevant sizes
         DWORD usage = (mUsage & TU_RENDERTARGET) ? D3DUSAGE_RENDERTARGET : 0;
-        UINT numMips = (mNumRequestedMipmaps == MIP_UNLIMITED) ? 
-            D3DX_DEFAULT : mNumRequestedMipmaps + 1;
+        UINT numMips = (mNumRequestedMipmaps == MIP_UNLIMITED) ? 0 : mNumRequestedMipmaps + 1;
         // Check dynamic textures
         if (mUsage & TU_DYNAMIC)
         {
@@ -623,14 +626,13 @@ namespace Ogre
 
 
         // create the texture
-        hr = D3DXCreateCubeTexture( 
-                d3d9Device,                                 // device
+        hr = d3d9Device->CreateCubeTexture(
                 static_cast<UINT>(mSrcWidth),               // dimension
                 numMips,                                    // number of mip map levels
                 usage,                                      // usage
                 d3dPF,                                      // pixel format
                 mD3DPool,
-                &textureResources->pCubeTex);               // data pointer
+                &textureResources->pCubeTex, NULL);
         // check result and except if failed
         if (FAILED(hr))
         {
@@ -705,14 +707,11 @@ namespace Ogre
 
         // determine which D3D9 pixel format we'll use
         HRESULT hr;
-        D3DFORMAT d3dPF = _chooseD3DFormat(d3d9Device);
-        // let's D3DX check the corrected pixel format
-        hr = D3DXCheckVolumeTextureRequirements(d3d9Device, NULL, NULL, NULL, NULL, 0, &d3dPF, mD3DPool);
+        D3DFORMAT d3dPF = D3D9Mappings::_getPF(mFormat);
 
         // Use D3DX to help us create the texture, this way it can adjust any relevant sizes
         DWORD usage = (mUsage & TU_RENDERTARGET) ? D3DUSAGE_RENDERTARGET : 0;
-        UINT numMips = (mNumRequestedMipmaps == MIP_UNLIMITED) ? 
-            D3DX_DEFAULT : mNumRequestedMipmaps + 1;
+        UINT numMips = (mNumRequestedMipmaps == MIP_UNLIMITED) ? 0 : mNumRequestedMipmaps + 1;
         // Check dynamic textures
         if (mUsage & TU_DYNAMIC)
         {
@@ -773,8 +772,7 @@ namespace Ogre
 
 
         // create the texture
-        hr = D3DXCreateVolumeTexture(   
-                d3d9Device,                                 // device
+        hr = d3d9Device->CreateVolumeTexture(
                 static_cast<UINT>(mWidth),                  // dimension
                 static_cast<UINT>(mHeight),
                 static_cast<UINT>(mDepth),
@@ -782,7 +780,7 @@ namespace Ogre
                 usage,                                      // usage
                 d3dPF,                                      // pixel format
                 mD3DPool,
-                &textureResources->pVolumeTex);             // data pointer
+                &textureResources->pVolumeTex, NULL);
         // check result and except if failed
         if (FAILED(hr))
         {
@@ -1051,20 +1049,6 @@ namespace Ogre
         return hr == D3D_OK;
     }
     /****************************************************************************************/
-    D3DFORMAT D3D9Texture::_chooseD3DFormat(IDirect3DDevice9* d3d9Device)
-    {       
-        // Choose frame buffer pixel format in case PF_UNKNOWN was requested
-        if(mFormat == PF_UNKNOWN)
-        {   
-            D3D9Device* device = D3D9RenderSystem::getDeviceManager()->getDeviceFromD3D9Device(d3d9Device);
-            
-            return device->getBackBufferFormat();       
-        }
-
-        // Choose closest supported D3D format as a D3D format
-        return D3D9Mappings::_getPF(D3D9Mappings::_getClosestSupportedPF(mFormat));
-    }
-    /****************************************************************************************/
     // Macro to hide ugly cast
     #define GETLEVEL(face,mip) \
         static_cast<D3D9HardwarePixelBuffer*>(mSurfaceList[face*(mNumMipmaps+1)+mip].get())
@@ -1410,14 +1394,23 @@ namespace Ogre
     {
         if(name == "DDBACKBUFFER")
         {
+            auto device = D3D9RenderSystem::getActiveD3D9Device();
+            auto d3dBuffer = static_cast<D3D9HardwarePixelBuffer*>(mBuffer);
+
+            if(PixelUtil::isDepth(mBuffer->getFormat()))
+            {
+                *static_cast<IDirect3DSurface9**>(pData) = d3dBuffer->getNullSurface(device);
+                return;
+            }
+
             if (mFSAA > 0)
             {
                 // rendering to AA surface
-                *(IDirect3DSurface9**)pData = static_cast<D3D9HardwarePixelBuffer*>(mBuffer)->getFSAASurface(D3D9RenderSystem::getActiveD3D9Device());
+                *(IDirect3DSurface9**)pData = d3dBuffer->getFSAASurface(device);
             }
             else
             {
-                *(IDirect3DSurface9**)pData = static_cast<D3D9HardwarePixelBuffer*>(mBuffer)->getSurface(D3D9RenderSystem::getActiveD3D9Device());
+                *(IDirect3DSurface9**)pData = d3dBuffer->getSurface(device);
             }
         }
         else if(name == "HWND")
