@@ -48,23 +48,14 @@ namespace Ogre {
 
     #define _MAX_CLASS_NAME_ 128
 
-    Win32Window::Win32Window(Win32GLSupport &glsupport):
-        mGLSupport(glsupport),
-        mContext(0)
+    Win32Window::Win32Window(Win32GLSupport &glsupport): GLWindow(),
+        mGLSupport(glsupport)
     {
-        mIsFullScreen = false;
         mHWnd = 0;
         mGlrc = 0;
-        mIsExternal = false;
-        mIsExternalGLControl = false;
         mOwnsGLContext = true;
         mSizing = false;
-        mClosed = false;
-        mHidden = false;
-        mVSync = false;
-        mVSyncInterval = 1;
         mDisplayFrequency = 0;
-        mActive = false;
         mDeviceName = NULL;
         mWindowedWinStyle = 0;
         mFullscreenWinStyle = 0;
@@ -107,7 +98,6 @@ namespace Ogre {
         mColourDepth = mIsFullScreen? 32 : GetDeviceCaps(GetDC(0), BITSPIXEL);
         int left = -1; // Defaults to screen center
         int top = -1; // Defaults to screen center
-        HWND parent = 0;
         WNDPROC windowProc = DefWindowProc;
         String title = name;
         bool hidden = false;
@@ -168,7 +158,8 @@ namespace Ogre {
 
 
 
-            if ((opt = miscParams->find("externalWindowHandle")) != end)
+            if ((opt = miscParams->find("parentWindowHandle")) != end ||
+                (opt = miscParams->find("externalWindowHandle")) != end)
             {
                 mHWnd = (HWND)StringConverter::parseSizeT(opt->second);
                 if (mHWnd)
@@ -237,10 +228,6 @@ namespace Ogre {
                 }
             }
 
-            // incompatible with fullscreen
-            if ((opt = miscParams->find("parentWindowHandle")) != end)
-                parent = (HWND)StringConverter::parseSizeT(opt->second);
-
             if ((opt = miscParams->find("windowProc")) != end)
                 windowProc = reinterpret_cast<WNDPROC>(StringConverter::parseSizeT(opt->second));
 
@@ -292,22 +279,13 @@ namespace Ogre {
             mFullscreenWinStyle = (hidden ? 0 : WS_VISIBLE) | WS_CLIPCHILDREN | WS_POPUP;
             mWindowedWinStyle   = (hidden ? 0 : WS_VISIBLE) | WS_CLIPCHILDREN;
             
-            if (parent)
-            {
-                mWindowedWinStyle |= WS_CHILD;
-            }
+            if (border == "none")
+                mWindowedWinStyle |= WS_POPUP;
+            else if (border == "fixed")
+                mWindowedWinStyle |= WS_OVERLAPPED | WS_BORDER | WS_CAPTION |
+                WS_SYSMENU | WS_MINIMIZEBOX;
             else
-            {
-                if (border == "none")
-                    mWindowedWinStyle |= WS_POPUP;
-                else if (border == "fixed")
-                    mWindowedWinStyle |= WS_OVERLAPPED | WS_BORDER | WS_CAPTION |
-                    WS_SYSMENU | WS_MINIMIZEBOX;
-                else
-                    mWindowedWinStyle |= WS_OVERLAPPEDWINDOW;
-
-            }
-
+                mWindowedWinStyle |= WS_OVERLAPPEDWINDOW;
 
             // No specified top left -> Center the window in the middle of the monitor
             if (left == -1 || top == -1)
@@ -415,7 +393,7 @@ namespace Ogre {
 
             // Pass pointer to self as WM_CREATE parameter
             mHWnd = CreateWindowEx(dwStyleEx, "OgreGLWindow", title.c_str(),
-                getWindowStyle(fullScreen), mLeft, mTop, mWidth, mHeight, parent, 0, hInst, this);
+                getWindowStyle(fullScreen), mLeft, mTop, mWidth, mHeight, 0, 0, hInst, this);
 
             LogManager::getSingleton().stream()
                 << "Created Win32Window '"
@@ -481,17 +459,8 @@ namespace Ogre {
         }
         if (mOwnsGLContext)
         {
-            mGlrc = wglCreateContext(mHDC);
-            if (!mGlrc)
-                OGRE_EXCEPT(Exception::ERR_RENDERINGAPI_ERROR, 
-                "wglCreateContext failed: " + translateWGLError(), "Win32Window::create");
-        }
-
-        if (old_context && old_context != mGlrc)
-        {
-            // Share lists with old context
-            if (!wglShareLists(old_context, mGlrc))
-                OGRE_EXCEPT(Exception::ERR_RENDERINGAPI_ERROR, "wglShareLists() failed", " Win32Window::create");
+            // New context is shared with previous one
+            mGlrc = mGLSupport.createNewContext(mHDC, old_context);
         }
 
         if (!wglMakeCurrent(mHDC, mGlrc))
@@ -514,7 +483,7 @@ namespace Ogre {
         }
 
         // Create RenderSystem context
-        mContext = new Win32Context(mHDC, mGlrc);
+        mContext = new Win32Context(mHDC, mGlrc, mGLSupport);
 
         mActive = true;
         setHidden(hidden);
@@ -716,11 +685,6 @@ namespace Ogre {
         return (mHWnd && !IsIconic(mHWnd));
     }
 
-    bool Win32Window::isClosed() const
-    {
-        return mClosed;
-    }
-
     void Win32Window::setHidden(bool hidden)
     {
         mHidden = hidden;
@@ -758,23 +722,6 @@ namespace Ogre {
         }
     }
 
-    void Win32Window::setVSyncInterval(unsigned int interval)
-    {
-        mVSyncInterval = interval;
-        if (mVSync)
-            setVSyncEnabled(true);
-    }
-
-    bool Win32Window::isVSyncEnabled() const
-    {
-        return mVSync;
-    }
-
-    unsigned int Win32Window::getVSyncInterval() const
-    {
-        return mVSyncInterval;
-    }
-
     void Win32Window::reposition(int left, int top)
     {
         if (mHWnd && !mIsFullScreen)
@@ -786,7 +733,10 @@ namespace Ogre {
 
     void Win32Window::resize(unsigned int width, unsigned int height)
     {
-        if (mHWnd && !mIsFullScreen)
+        if (!isVisible())
+            return;
+
+        if (!mIsExternal && !mIsFullScreen && width > 0 && height > 0)
         {
             RECT rc = { 0, 0, int(width), int(height) };
             AdjustWindowRect(&rc, getWindowStyle(mIsFullScreen), false);
@@ -794,12 +744,15 @@ namespace Ogre {
             height = rc.bottom - rc.top;
             SetWindowPos(mHWnd, 0, 0, 0, width, height,
                 SWP_NOMOVE | SWP_NOZORDER | SWP_NOACTIVATE);
+            return;
         }
+
+        updateWindowRect();
     }
 
     void Win32Window::windowMovedOrResized()
     {
-        if (!mHWnd || IsIconic(mHWnd))
+        if (!isVisible())
             return;
 
         updateWindowRect();     
@@ -859,23 +812,6 @@ namespace Ogre {
       }
     }
 
-    void Win32Window::copyContentsToMemory(const Box& src, const PixelBox &dst, FrameBuffer buffer)
-    {
-        if(src.right > mWidth || src.bottom > mHeight || src.front != 0 || src.back != 1
-        || dst.getWidth() != src.getWidth() || dst.getHeight() != src.getHeight() || dst.getDepth() != 1)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS, "Invalid box.", "Win32Window::copyContentsToMemory");
-        }
-
-        if (buffer == FB_AUTO)
-        {
-            buffer = mIsFullScreen? FB_FRONT : FB_BACK;
-        }
-
-        static_cast<GLRenderSystemCommon*>(Root::getSingleton().getRenderSystem())
-                ->_copyContentsToMemory(getViewport(0), src, dst, buffer);
-    }
-
     void Win32Window::getCustomAttribute( const String& name, void* pData )
     {
         if( name == "GLCONTEXT" ) {
@@ -936,6 +872,4 @@ namespace Ogre {
             }
         }
     }
-
-    GLContext* Win32Window::getContext() const { return mContext; }
 }
