@@ -126,12 +126,6 @@ namespace Ogre
         return strName;
     }
     //-------------------------------------------------------------------------
-    const String& MetalRenderSystem::getFriendlyName(void) const
-    {
-        static String strName("Metal_RS");
-        return strName;
-    }
-    //-------------------------------------------------------------------------
     HardwareOcclusionQuery* MetalRenderSystem::createHardwareOcclusionQuery(void)
     {
         return 0; //TODO
@@ -198,14 +192,8 @@ namespace Ogre
 
         //These don't make sense on Metal, so just use flexible defaults.
         rsc->setVertexProgramConstantFloatCount( 16384 );
-        rsc->setVertexProgramConstantBoolCount( 16384 );
-        rsc->setVertexProgramConstantIntCount( 16384 );
         rsc->setFragmentProgramConstantFloatCount( 16384 );
-        rsc->setFragmentProgramConstantBoolCount( 16384 );
-        rsc->setFragmentProgramConstantIntCount( 16384 );
         rsc->setComputeProgramConstantFloatCount( 16384 );
-        rsc->setComputeProgramConstantBoolCount( 16384 );
-        rsc->setComputeProgramConstantIntCount( 16384 );
 
 #if OGRE_PLATFORM != OGRE_PLATFORM_APPLE_IOS
         uint8 mrtCount = 8u;
@@ -859,10 +847,18 @@ namespace Ogre
             [mActiveRenderEncoder setVertexBuffer:mtlbuf->getBufferName(unused) offset:0 atIndex:bufferIdx];
         }
 
+        if(mDepthStencilDescChanged)
+        {
+            mDepthStencilState =
+                    [mActiveDevice->mDevice newDepthStencilStateWithDescriptor:mDepthStencilDesc];
+            mDepthStencilDescChanged = false;
+        }
+
+        [mActiveRenderEncoder setDepthStencilState:mDepthStencilState];
+
         [mActiveRenderEncoder setRenderPipelineState:getPipelineState()];
 
         const size_t numberOfInstances = op.numberOfInstances;
-        const bool hasInstanceData = mCurrentVertexBuffer->vertexBufferBinding->hasInstanceData();
 
         // Render to screen!
         if( op.useIndexes )
@@ -923,7 +919,7 @@ namespace Ogre
                 const uint32 vertexStart = static_cast<uint32>( mCurrentVertexBuffer->vertexStart );
 #endif
 
-                if (hasInstanceData)
+                if (numberOfInstances > 1)
                 {
                     [mActiveRenderEncoder drawPrimitives:mCurrentPrimType
                                              vertexStart:vertexStart
@@ -990,14 +986,12 @@ namespace Ogre
         // update const buffer
         #if 1
         [mActiveRenderEncoder setVertexBytes:params->getFloatPointer(0)
-            length:params->getConstantList().size() atIndex:16];
+            length:params->getConstantList().size() atIndex:MetalProgram::UNIFORM_INDEX_START];
         #else
-        // TODO rather use this:
+        // TODO rather use this, but buffer seems to be never updated
         size_t unused;
-        mAutoParamsBuffer->writeData(0, params->getFloatConstantList().size()*sizeof(float), params->getFloatPointer(0));
-        [mActiveRenderEncoder setVertexBuffer:mAutoParamsBuffer->getBufferName(unused) offset:0 atIndex:16];
-        // or
-        // shader->updateBuffers( params, mAutoParamsBuffer->lockImpl()  );
+        mAutoParamsBuffer->writeData(0, params->getConstantList().size(), params->getFloatPointer(0));
+        [mActiveRenderEncoder setVertexBuffer:mAutoParamsBuffer->getBufferName(unused) offset:0 atIndex:MetalProgram::UNIFORM_INDEX_START];
         #endif
     }
     //-------------------------------------------------------------------------
@@ -1033,27 +1027,6 @@ namespace Ogre
         }
     }
     //-------------------------------------------------------------------------
-    void MetalRenderSystem::discardFrameBuffer( unsigned int buffers )
-    {
-        if( buffers & FBT_COLOUR )
-        {
-            for( size_t i=0; i<mNumMRTs; ++i )
-            {
-                if( mCurrentColourRTs[i] )
-                    mCurrentColourRTs[i]->mColourAttachmentDesc.loadAction = MTLLoadActionDontCare;
-            }
-        }
-
-        if( mCurrentDepthBuffer )
-        {
-            if( buffers & FBT_DEPTH && mCurrentDepthBuffer->mDepthAttachmentDesc )
-                mCurrentDepthBuffer->mDepthAttachmentDesc.loadAction = MTLLoadActionDontCare;
-
-            if( buffers & FBT_STENCIL && mCurrentDepthBuffer->mStencilAttachmentDesc )
-                mCurrentDepthBuffer->mStencilAttachmentDesc.loadAction = MTLLoadActionDontCare;
-        }
-    }
-    //-------------------------------------------------------------------------
     Real MetalRenderSystem::getMinimumDepthInputValue(void)
     {
         return 0.0f;
@@ -1085,16 +1058,15 @@ namespace Ogre
 
         mActiveRenderTarget = target;
 
-        if( target )
+        if( auto metalTarget = dynamic_cast<MetalRenderTargetCommon*>(target) )
         {
             //if( target->getForceDisableColourWrites() )
             //    viewportRenderTargetFlags &= ~VP_RTT_COLOUR_WRITE;
 
-            mCurrentColourRTs[0] = 0;
+            mCurrentColourRTs[0] = metalTarget;
             //We need to set mCurrentColourRTs[0] to grab the active device,
             //even if we won't be drawing to colour target.
             target->getCustomAttribute( "mNumMRTs", &mNumMRTs );
-            target->getCustomAttribute( "MetalRenderTargetCommon", &mCurrentColourRTs[0] );
 
             MetalDevice *ownerDevice = 0;
 
@@ -1156,50 +1128,6 @@ namespace Ogre
         }
     }
     //-------------------------------------------------------------------------
-    void MetalRenderSystem::_notifyCompositorNodeSwitchedRenderTarget( RenderTarget *previousTarget )
-    {
-        if( previousTarget )
-        {
-            bool mustClear = false;
-            uint8 numMRTs = 0;
-            MetalRenderTargetCommon *currentColourRTs[OGRE_MAX_MULTIPLE_RENDER_TARGETS];
-            previousTarget->getCustomAttribute( "mNumMRTs", &numMRTs );
-            previousTarget->getCustomAttribute( "MetalRenderTargetCommon", &currentColourRTs[0] );
-
-            for( size_t i=0; i<numMRTs; ++i )
-            {
-                if( currentColourRTs[i] )
-                {
-                    if( currentColourRTs[i]->mColourAttachmentDesc.loadAction == MTLLoadActionClear )
-                        mustClear = true;
-                }
-            }
-
-            MetalDepthBuffer *depthBuffer = static_cast<MetalDepthBuffer*>(
-                        previousTarget->getDepthBuffer() );
-
-            if( depthBuffer )
-            {
-                if( depthBuffer->mDepthAttachmentDesc &&
-                    depthBuffer->mDepthAttachmentDesc.loadAction == MTLLoadActionClear )
-                {
-                    mustClear = true;
-                }
-                if( depthBuffer->mStencilAttachmentDesc &&
-                    depthBuffer->mStencilAttachmentDesc.loadAction == MTLLoadActionClear )
-                {
-                    mustClear = true;
-                }
-            }
-
-            if( mustClear )
-            {
-                _setRenderTarget( previousTarget );
-                createRenderEncoder();
-            }
-        }
-    }
-    //-------------------------------------------------------------------------
     void MetalRenderSystem::initGPUProfiling(void)
     {
 #if OGRE_PROFILING
