@@ -37,29 +37,7 @@ same license as the rest of the engine.
 #include "GBufferSchemeHandler.h"
 #include "NullSchemeHandler.h"
 
-#include "SharedData.h"
-
-namespace Ogre
-{
-    template<> SharedData* Singleton<SharedData>::msSingleton = 0;
-}
-
-SharedData::SharedData()
-    : iRoot(0), iCamera(0), iWindow(0), iSystem(0), iActivate(false),
-      iGlobalActivate(false), iMainLight(0)
-{
-}
-
-SharedData::~SharedData() {}
-
-SharedData* SharedData::getSingletonPtr(void)
-{
-    return msSingleton;
-}
-SharedData& SharedData::getSingleton(void)
-{
-    assert( msSingleton );  return ( *msSingleton );
-}
+#include "OgreShaderExGBuffer.h"
 
 using namespace Ogre;
 
@@ -162,6 +140,10 @@ void DeferredShadingSystem::setActive(bool active)
         mActive = active;
         mGBufferInstance->setEnabled(active);
 
+        RTShader::ShaderGenerator& rtShaderGen = RTShader::ShaderGenerator::getSingleton();
+        // we do lights ourselves if active
+        rtShaderGen.getRenderState(RTShader::ShaderGenerator::DEFAULT_SCHEME_NAME)->setLightCountAutoUpdate(!mActive);
+
         // mCurrentMode could have changed with a prior call to setMode, so iterate all
         setMode(mCurrentMode);
     }
@@ -176,6 +158,8 @@ void DeferredShadingSystem::createResources(void)
 {
     CompositorManager &compMan = CompositorManager::getSingleton();
 
+    RTShader::ShaderGenerator& rtShaderGen = RTShader::ShaderGenerator::getSingleton();
+
     //Hook up the compositor logic and scheme handlers.
     //This can theoretically happen in a loaded plugin, but in this case the demo contains the code.
     static bool firstTime = true;
@@ -186,9 +170,18 @@ void DeferredShadingSystem::createResources(void)
 
         compMan.registerCustomCompositionPass("DeferredLight", new DeferredLightCompositionPass);
 
+        rtShaderGen.createScheme("GBuffer");
+
         firstTime = false;
     }
 
+
+    RTShader::RenderState* schemRenderState = rtShaderGen.getRenderState("GBuffer");
+    schemRenderState->setLightCountAutoUpdate(false); // does not use lights
+    RTShader::GBuffer* subRenderState = rtShaderGen.createSubRenderState<RTShader::GBuffer>();
+    subRenderState->setOutBuffers({RTShader::GBuffer::TL_DIFFUSE_SPECULAR, RTShader::GBuffer::TL_NORMAL_VIEWDEPTH});
+    schemRenderState->addTemplateSubRenderState(subRenderState);
+
     mCompositorLogics["SSAOLogic"] = new SSAOLogic;
     compMan.registerCompositorLogic("SSAOLogic", mCompositorLogics["SSAOLogic"]);
 
